Documentation
¶
Index ¶
- type Apt
- type Base
- type Feeder
- func NewAptFeeder(conf map[string]string) (Feeder, error)
- func NewFeeder(rule string, name string, conf map[string]string, bus EventBus.Bus, id int32) (Feeder, error)
- func NewFileFeeder(conf map[string]string) (Feeder, error)
- func NewFolderFeeder(conf map[string]string) (Feeder, error)
- func NewImapFeeder(conf map[string]string) (Feeder, error)
- func NewRSSFeeder(conf map[string]string) (Feeder, error)
- func NewSlackFeeder(conf map[string]string) (Feeder, error)
- func NewTelegramFeeder(conf map[string]string) (Feeder, error)
- func NewTimerFeeder(conf map[string]string) (Feeder, error)
- func NewTwitterFeeder(conf map[string]string) (Feeder, error)
- func NewWebFeeder(conf map[string]string) (Feeder, error)
- func NewWebRSSFeeder(conf map[string]string) (Feeder, error)
- type FeederFactory
- type File
- type Folder
- type Imap
- type RSS
- type Slack
- type Telegram
- type Terminal
- func (Terminal) AcceptTermsOfService(ctx context.Context, tos tg.HelpTermsOfService) error
- func (Terminal) Code(ctx context.Context, sentCode *tg.AuthSentCode) (string, error)
- func (Terminal) Password(_ context.Context) (string, error)
- func (a Terminal) Phone(_ context.Context) (string, error)
- func (Terminal) SignUp(ctx context.Context) (auth.UserInfo, error)
- type Timer
- type Twitter
- type Web
- type WebRSS
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Apt ¶ added in v1.11.3
type Apt struct {
Base
// contains filtered or unexported fields
}
Apt is a Feeder that creates a stream from a Apt feed
type Base ¶
type Base struct {
// contains filtered or unexported fields
}
Base is inherited from the feeders
func (*Base) GetIdentifier ¶
GetIdentifier returns the Node identifier ID used in the bus
type Feeder ¶
type Feeder interface {
Name() string
Rule() string
Start()
Stop()
IsRunning() bool
GetIdentifier() string
OnEvent(e *data.Event)
// contains filtered or unexported methods
}
Feeder defines Base methods of the object
func NewAptFeeder ¶ added in v1.11.3
NewAptFeeder is the registered method to instantiate a AptFeeder
func NewFeeder ¶
func NewFeeder(rule string, name string, conf map[string]string, bus EventBus.Bus, id int32) (Feeder, error)
NewFeeder creates a new registered Feeder from it's name
func NewFileFeeder ¶
NewFileFeeder is the registered method to instantiate a FileFeeder
func NewFolderFeeder ¶ added in v0.10.0
NewFolderFeeder is the registered method to instantiate a FolderFeeder
func NewImapFeeder ¶ added in v1.20.0
NewFolderFeeder is the registered method to instantiate a FolderFeeder
func NewRSSFeeder ¶
NewRSSFeeder is the registered method to instantiate a RSSFeeder
func NewSlackFeeder ¶ added in v0.9.1
NewSlackFeeder is the registered method to instantiate a SlackFeeder
func NewTelegramFeeder ¶ added in v1.26.9
NewTelegramFeeder is the registered method to instantiate a TelegramFeeder
func NewTimerFeeder ¶ added in v1.1.7
NewTimerFeeder is the registered method to instantiate a TimerFeeder
func NewTwitterFeeder ¶
NewTwitterFeeder is the registered method to instantiate a TwitterFeeder https://developer.twitter.com/en/docs/tweets/filter-realtime/guides/basic-stream-parameters
func NewWebFeeder ¶
NewWebFeeder is the registered method to instantiate a WebFeeder
type FeederFactory ¶
FeederFactory identifies a function to instantiate a Feeder using the Factory
type File ¶
type File struct {
Base
// contains filtered or unexported fields
}
File is a Feeder that creates a stream from a file
type Folder ¶ added in v0.10.0
type Folder struct {
Base
// contains filtered or unexported fields
}
Folder is a Feeder that creates a stream from a folder
type Imap ¶ added in v1.20.0
type Imap struct {
Base
// contains filtered or unexported fields
}
Imap is a Feeder that creates a stream from an IMAP server
type RSS ¶
type RSS struct {
Base
// contains filtered or unexported fields
}
RSS is a Feeder that creates a stream from a RSS feed
type Slack ¶ added in v0.9.1
type Slack struct {
Base
Team string
User string
TeamID string
UserID string
BotID string
// contains filtered or unexported fields
}
Slack is a Feeder that get events from Slack
type Telegram ¶ added in v1.26.9
type Telegram struct {
Base
// contains filtered or unexported fields
}
type Terminal ¶ added in v1.26.9
type Terminal struct {
PhoneNumber string // optional, will be prompted if empty
}
func (Terminal) AcceptTermsOfService ¶ added in v1.26.9
type Timer ¶ added in v1.1.7
type Timer struct {
Base
// contains filtered or unexported fields
}
Timer is a Feeder that triggers the pipeline using a timer
type Twitter ¶
type Twitter struct {
Base
// contains filtered or unexported fields
}
Twitter is a Feeder that feeds a pipeline with tweets
type Web ¶
type Web struct {
Base
// contains filtered or unexported fields
}
Web is a Feeder that creates a stream from an URL
type WebRSS ¶ added in v1.26.9
type WebRSS struct {
Base
// contains filtered or unexported fields
}
WebRSS is a Feeder that scrapes a website and emits one Message per article found